# Contributions guidelines

Everyone interested in contributing to the project is ecouraged to do so.
In order to create a community and to coordinate the contribution we deligned some guidelines 
and a standard environment for developer.
The aim is to provide a quick, easy and standardized way for contributors to help in a meaningful way 
so that anyone can focus on his work other without interfering in a destructive way with the one of others. 
Everything to know (or in the preliminary phase everything we manage to include) in that reguard is documented in the **TODO**[section dedicated]() in the documentation.

All the guidelines are just our current workflow, feel free to give your feedback and contribute to it highlights what to improve or change.

> **Please read the [code of conduct](CODE_OF_CONDUCT.md) before any contribution**

For any remaining question or just to contact us feel free to join our **TODO** [telegram group]()

# Contribution for the website

It is possible to contribute to the source of the [*website*](https://www.freeports.org) of the project from the [**GitHub repository**](https://github.com/GVoreste/analysis_finance_reports_website).